TimerDuration

Enum TimerDuration 

pub enum TimerDuration {
    Elapsed,
    Real(Duration),
    Infinite,
}
A duration wrapper supporting elapsed/negative, real, and infinite durations. Due to the solar system’s impending collapse before the 64 bit integer limit of seconds is reached, an Infinite duration is translated to that when turning this back info a normal duration. If you run your program for longer than the sun’s entire lifespan including the past, this may cause an issue. But I think you’ll have much bigger issues long before that, including the fact that you even came up with that idea.

Variants



Elapsed



Real(Duration)



Infinite

Implementations

Source

impl TimerDuration

pub fn from_difference(a: TimerDuration, b: Duration) -> TimerDuration

Takes the difference between a TimerDuration a and a Duration b, resulting in either a negative (Elapsed) duration or a Real one. The Infinite duration is passed through as-is, with no subtraction done to it.

pub fn to_real(&self) -> Duration

Converts this into a Duration that is waitable by rust’s standard functions, for use in e.g. specifying timeouts to std operations.

pub const fn is_elapsed(&self) -> bool

pub const fn is_real(&self) -> bool

pub const fn is_infinite(&self) -> bool